bbb = r'https://d.docs.live.net/9122e41a29eea899/sb_yufengguang/xls/%E9%A2%84%E7%AE%97_20250507200254726580.xlsx'
aaa = '预算_20250507200254726580'
bbb

import f_excel.d单函数.open_or_add_process_excel_with_r1c1 as op


op.open_or_add_process_excel_with_r1c1_0(bbb)

from time import *
sleep(10)