
bbb = r"https://d.docs.live.net/9122e41a29eea899/sb_yufengguang/xls/72-101-D17103ET10-%20bom%20%20ASM%20%E9%9D%9E%E5%B8%B8%E9%87%8D%E8%A6%81%20_20250507183543380991.xlsx"

import f_excel.d单函数.open_or_add_process_excel_with_r1c1 as op


op.open_or_add_process_excel_with_r1c1_0(bbb)

from time import *
sleep(10)