import f_excel.d单函数.open_or_add_process_excel_with_r1c1 as op

aaa =r"中美日内瓦贸易协议_2025workbook_xls__20250512170120056179"

bbb =r"https://d.docs.live.net/9122e41a29eea899/sb_yufengguang/xls/%E4%B8%AD%E7%BE%8E%E6%97%A5%E5%86%85%E7%93%A6%E8%B4%B8%E6%98%93%E5%8D%8F%E8%AE%AE_2025workbook_xls__20250512170120056179.xlsx"









op.open_or_add_process_excel_with_r1c1_0(bbb)